load(file = "./101multiOmic_subtype.RData")
library(limma)
library(RColorBrewer)
pal.subtype <- brewer.pal(4, "Set1")
pal.path <- brewer.pal(5, "Paired")
pal.tissue <- brewer.pal(7, "Set2")

#read CNA table , tidying up , match with eSet dataset
cnv.df <- read.delim("./datasets/prad_su2c_2019/data_CNA.txt", header = T, 
                     stringsAsFactors = F)
colnames(eSet)
colnames(cnv.df) <- gsub("\\.", "_", colnames(cnv.df))
cnv.df <- cnv.df[,c(1,match(colnames(eSet), colnames(cnv.df)))]
rownames(cnv.df) <- cnv.df$Hugo_Symbol
cnv.df <- cnv.df[,-1]
keep <- intersect(rownames(eSet), rownames(cnv.df))
cnv.df <- cnv.df[keep,]

eSet <- eSet[keep, ]

#FAIL---skip:individual sample CNV vs Exp boxplot
estimate = numeric(ncol(eSet))
p = numeric(ncol(eSet))
pdf("./plots/101.1Boxplot_su2c_CNV&Exp.pdf", width = 4, height = 4)
for (i in 1:ncol(eSet)) {
  tmp.df <- cbind(scale(eSet[,i], center = T, scale = T), cnv.df[,i])
  colnames(tmp.df) <- c("Exp", "CNA")
  boxplot(Exp ~ CNA, data = tmp.df, col = brewer.pal(5, "RdPu"), 
          main = colnames(eSet)[i], ylab = "Z score")
  
  test <- cor.test(tmp.df[,1], tmp.df[,2])
  estimate[i] <- test$estimate
  p[i] <- test$p.value
  print(i)

}
dev.off()

cna.cor <- data.frame(estimate = estimate , p = p , subtype = info.Abida2019$subtype)
aggregate(estimate ~ subtype, data = cna.cor, FUN = median )


#FAIL---skip:calculate the median of gene expression in each subtype, and then plot 
tmp <- as.data.frame(t(eSet))
tmp$subtype <- info.Abida2019$subtype

gene.median <- data.frame(subtype = c("subtype1", "subtype2", "subtype3", "subtype4"))
for (i  in 1:nrow(eSet)) {
  gene.median[,i+1] <- aggregate(tmp[,i] ~ subtype, data = tmp, FUN = median)[,2]
  print(i)
}
rownames(gene.median) <- gene.median$subtype
gene.median <- gene.median[,-1]
colnames(gene.median) <- rownames(eSet)
gene.median <- as.data.frame(t(gene.median))
boxplot()


#should look at cnv in each subtype 
cnv.df <- as.data.frame(t(cnv.df))
cnv.df$subtype <- info.Abida2019$subtype
cnv.median <- data.frame(subtype = c("subtype1", "subtype2", "subtype3", "subtype4"))
for (i  in c(1:17628)) {
  tmp <- aggregate(cnv.df[,i] ~ subtype, data = cnv.df, FUN = median, na.rm = TRUE)[,2]
  cnv.median <- cbind(cnv.median, tmp)
  print(i)
}
cnv.median[,1:20]
rownames(cnv.median) <- cnv.median$subtype
cnv.median <- cnv.median[,-1]
cnv.median <- as.matrix(t(cnv.median))
cnv.median <- as.matrix(apply(cnv.median , 2, as.numeric))
rownames(cnv.median) <- colnames(cnv.df)[1:17628]

#cnv.media.sig <- cnv.median[apply(cnv.median, 1, function(x) !all(x==0)),]
#which(cnv.media.sig[,4] == -2)

#CNA plot
library(DNAcopy)
gene.coor  <- read.table("./datasets/mRNA_name_coor.txt", header = T, row.names = 1,
                     skip = 1)
keep <- intersect(rownames(gene.coor), rownames(cnv.median))
gene.coor <- gene.coor[keep,]
cnv.median <- cnv.median[keep,]

gene.coor$Chr <- gsub(".*;", "", gene.coor$Chr) # retain only one coordinate
gene.coor$Start <- gsub(".*;", "", gene.coor$Start) # retain only one coordinate
gene.coor$End <- gsub(".*;", "", gene.coor$End) # retain only one coordinate
gene.coor$Length <- gsub(".*;", "", gene.coor$Length) # retain only one coordinate
gene.coor$Length <- as.integer(gene.coor$Length) # retain only one coordinate
gene.coor$Start <- as.integer(gene.coor$Start) # retain only one coordinate
gene.coor$pos <- gene.coor$Start + (gene.coor$Length/2)
gene.coor$Chr <- gsub("X", "22", gene.coor$Chr)
gene.coor$Chr <- gsub("Y", "23", gene.coor$Chr)
gene.coor$Chr <- as.numeric(gene.coor$Chr) 


cna.coor <- data.frame(Clone = rownames(cnv.median), 
                       Chromosome = gene.coor$Chr,
                       Position = gene.coor$pos, 
                       subtype1 = cnv.median[,1],
                       subtype2 = cnv.median[,2],
                       subtype3 = cnv.median[,3],
                       subtype4 = cnv.median[,4],
                       stringsAsFactors = F)

pdf("./plots/101.1CNAplot_Abida_median.pdf", width = 7, height = 4)
CNA.object <- CNA(cbind(cna.coor$subtype1),
                  cna.coor$Chromosome,cna.coor$Position,
                  data.type="logratio",sampleid="subtype1")
smoothed.CNA.object <- smooth.CNA(CNA.object)
segment.smoothed.CNA.object <- segment(smoothed.CNA.object, 
                                       alpha = 0.01, undo.splits = "sdundo", undo.SD = 100,
                                       verbose=1)
plot(segment.smoothed.CNA.object, plot.type="w", ylim = c(-2,2))
abline(h=c(-1,1), col = "darkblue", lwd=1, lty=2)

CNA.object <- CNA(cbind(cna.coor$subtype2),
                  cna.coor$Chromosome,cna.coor$Position,
                  data.type="logratio",sampleid="subtype2")
smoothed.CNA.object <- smooth.CNA(CNA.object)
segment.smoothed.CNA.object <- segment(smoothed.CNA.object, 
                                       alpha = 0.01, undo.splits = "sdundo", undo.SD = 100,
                                       verbose=1)
plot(segment.smoothed.CNA.object, plot.type="w", ylim = c(-2,2))
abline(h=c(-1,1), col = "darkblue", lwd=1, lty=2)

CNA.object <- CNA(cbind(cna.coor$subtype3),
                  cna.coor$Chromosome,cna.coor$Position,
                  data.type="logratio",sampleid="subtype3")
smoothed.CNA.object <- smooth.CNA(CNA.object)
segment.smoothed.CNA.object <- segment(smoothed.CNA.object, 
                                       alpha = 0.01, undo.splits = "sdundo", undo.SD = 100,
                                       verbose=1)
plot(segment.smoothed.CNA.object, plot.type="w", ylim = c(-2,2))
abline(h=c(-1,1), col = "darkblue", lwd=1, lty=2)

CNA.object <- CNA(cbind(cna.coor$subtype4),
                  cna.coor$Chromosome,cna.coor$Position,
                  data.type="logratio",sampleid="subtype4")
smoothed.CNA.object <- smooth.CNA(CNA.object)
segment.smoothed.CNA.object <- segment(smoothed.CNA.object, 
                                       alpha = 0.01, undo.splits = "sdundo", undo.SD = 100,
                                       verbose=1)
plot(segment.smoothed.CNA.object, plot.type="w", ylim = c(-2,2))
abline(h=c(-1,1), col = "darkblue", lwd=1, lty=2)

dev.off()
