####pre-processing and taming#####
info.Abida2019 <- read.csv("./datasets/prad_su2c_2019/sampleinfo.csv", header = T,
                           stringsAsFactors = F)
rownames(info.Abida2019)
info.Abida2019$Sample.ID <- gsub("-", "_", info.Abida2019$Sample.ID)
info.Abida2019$Subject.ID <- paste0("Abida", info.Abida2019$Subject.ID)

FPKM1 <- read.delim("./datasets/prad_su2c_2019/data_mRNA_seq_fpkm_polya.txt", header = T, 
                   stringsAsFactors = F)
colnames(FPKM1)
colnames(FPKM1) <- gsub("\\.", "_", colnames(FPKM1))
FPKM1 <- FPKM1[which(!duplicated(FPKM1$Hugo_Symbol)),]
rownames(FPKM1) <- FPKM1$Hugo_Symbol
FPKM1 <- FPKM1[,-1]

#FPKM2 <- read.delim("./datasets/prad_su2c_2019/data_mRNA_seq_fpkm_capture.txt", header = T, stringsAsFactors = F)

keep <- intersect( info.Abida2019$Sample.ID, colnames(FPKM1))

mutation <- read.delim("./datasets/prad_su2c_2019/data_mutations_mskcc.txt", header = T, 
                       stringsAsFactors = F)
mutation$Tumor_Sample_Barcode
mutation$Tumor_Sample_Barcode <- gsub("\\.", "_", mutation$Tumor_Sample_Barcode)
mutation$Tumor_Sample_Barcode <- gsub("-", "_", mutation$Tumor_Sample_Barcode)

keep <- intersect(keep, mutation$Tumor_Sample_Barcode)

rownames(info.Abida2019) <- info.Abida2019$Sample.ID
info.Abida2019 <- info.Abida2019[keep,]
FPKM1 <- FPKM1[,keep]
mutation <- mutation[which(mutation$Tumor_Sample_Barcode %in% keep),]


save(info.Abida2019, FPKM1, mutation, 
     file = "./101multiOmic.RData")


#####
load(file = "./101multiOmic.RData")
library(ConsensusClusterPlus)
library(CancerSubtypes)
library(limma)
library(RColorBrewer)
pal.subtype <- brewer.pal(4, "Set1")
pal.path <- brewer.pal(5, "Paired")
pal.tissue <- brewer.pal(7, "Set2")
pal.mut <- brewer.pal(3, "Dark2")

info.Abida2019$Sample.Type
eSet <- log2(FPKM1+1)
eSet_cluster = sweep(eSet,1, apply(eSet,1,median,na.rm=T)) #median center dataset

#PCA
pdf("./plots/101PCA_Abida.pdf", width = 5, height = 5)
plotMDS(eSet, top = 1000, pch = 19, gene.selection = "common", 
        col=pal.tissue[factor(info.Abida2019$Sample.Type)], cex = 1)
legend("topright", legend=levels(factor(info.Abida2019$Sample.Type)), text.col=pal.tissue,
       bg="white", cex=1)

plotMDS(eSet, top = 1000, pch = 19, gene.selection = "common", 
        col=pal.path[factor(info.Abida2019$Pathology.Classification)], cex = 1)
legend("topright", legend=levels(factor(info.Abida2019$Pathology.Classification)), text.col=pal.path,
       bg="white", cex=0.7)
dev.off()


#####met subtype clustering#######
title= c("./Subtype_cluster/Abida")
eSet_cluster <- as.matrix(eSet_cluster)
results = ConsensusClusterPlus(eSet_cluster, maxK=10,reps=50,pItem=0.8,pFeature=1,
                               title=title,clusterAlg="hc",distance="pearson",
                               seed=71279,plot="pdf")
results[[5]][["consensusMatrix"]][1:5,1:5]
results[[5]][["consensusTree"]]
results[[5]][["consensusClass"]][1:5]
consensus.Mat <- results[[5]][["consensusMatrix"]]
#save(consensus.Mat ,  file = "./Subtype_cluster/02ConsensusClusterPlus_Matrix.RData")
icl = calcICL(results,title=title,plot="pdf")
icl[["clusterConsensus"]]
icl[["itemConsensus"]][1:5,]
#clustering k = 5 is ideal subgroup for downstream analysis
subtype <- results[[5]][["consensusClass"]]
# from clustering, 5 subtypes is reasonable . 


#NMF
eSet <- as.matrix(eSet)
set.seed(1)
results.NMF2 <- ExecuteCNMF(eSet, 4, nrun = 5) # select 4 as the clusters number 
group2=results.NMF2$group
distanceMatrix2=results.NMF2$distanceMatrix
#silhouette
group.s2 <- group2[order(group2)]
consensus.Mat.s2 <- distanceMatrix2[order(group2),order(group2)]
sil2=silhouette_SimilarityMatrix(group.s2, consensus.Mat.s2)

info.Abida2019$subtype_num <- paste0("subtype", group2)

#Silhouette
colnames(sil2)

pdf("./plots/101SilhouettePlot_Abida_subtypename.pdf", width = 5, height = 5)
#plot(sil2 , col = pal.subtype[1:2])
plot(sil2 , col = pal.subtype[1:4])
dev.off()

#sig clust
pdf("./plots/101sigClust_Abida.pdf", width = 5, height = 4)
sigclust2=sigclustTest(eSet_cluster, group2, nsim=500, nrep=1, icovest=1)
#sigclust5=sigclustTest(eSet_cluster, group5, nsim=1000, nrep=1, icovest=1)
dev.off()

save(eSet, info.Abida2019, mutation, 
     file = "./101multiOmic_subtype.RData")


###HRR AR, NE
load("./HRR.rds")
load("./NE.rds")
load("./AR.rds")
load("./ETS.rds")
load("./ERG.rds")
load("./basal.rds")
load("./luminal.rds")
gene.sig <- c(NE, AR, basal, luminal)
gene.sig <- intersect(gene.sig, rownames(eSet))
gene.sig <- gene.sig[c(1:21,24:26,27:41)] 

library(pheatmap)
annotation_col = data.frame(
  Subtype = info.Abida2019$subtype_num, 
  Tissue = info.Abida2019$Sample.Type,
  Pathology = info.Abida2019$Pathology.Classification
)
rownames(annotation_col) = colnames(eSet)
order(info.Abida2019$subtype)

names(pal.subtype) <- levels(as.factor(info.Abida2019$subtype_num))
names(pal.tissue) <- levels(as.factor(info.Abida2019$Sample.Type))
names(pal.path) <- levels(as.factor(info.Abida2019$Pathology.Classification))
breaksList = seq(-2,3, by = 0.1)

pdf("./plots/101Heatmap_Abida.pdf", width = 7, height = 7)
pheatmap(eSet[gene.sig,order(info.Abida2019$subtype_num)], 
         scale = "row", clustering_distance_cols = "euclidean",
         clustering_method = "complete",
         show_rownames = T, show_colnames = F,
         fontsize_row = 10, fontsize_col = 1,
         cluster_cols = F, cluster_rows = F,
         annotation_legend = T, border_color = NA,
         color = colorRampPalette(rev(brewer.pal(n = 7, name = "RdYlBu")))(length(breaksList)), # Defines the vector of colors for the legend (it has to be of the same lenght of breaksList)
         breaks = breaksList, annotation_col = annotation_col,
         annotation_colors  = list(
           Subtype = pal.subtype, 
           Tissue = pal.tissue, 
           Pathology = pal.path
         ),
         main = "HRR NE AR"
)

dev.off()
#subtype1 == Basal , subtype2 == HRR, subtype3 == NE, subtype4 == Luminal
info.Abida2019$subtype_anno <- info.Abida2019$subtype_num
info.Abida2019$subtype_anno[grep("subtype1", info.Abida2019$subtype_num )] <- "Basal"
info.Abida2019$subtype_anno[grep("subtype2",  info.Abida2019$subtype_num )] <- "HRR"
info.Abida2019$subtype_anno[grep("subtype3",  info.Abida2019$subtype_num )] <- "NE"
info.Abida2019$subtype_anno[grep("subtype4",  info.Abida2019$subtype_num )] <- "Luminal"


annotation_col = data.frame(
  Subtype = info.Abida2019$subtype_anno, 
  Tissue = info.Abida2019$Sample.Type,
  Pathology = info.Abida2019$Pathology.Classification
)
rownames(annotation_col) = colnames(eSet)
order(info.Abida2019$subtype)

names(pal.subtype) <- levels(as.factor(info.Abida2019$subtype_anno))
names(pal.tissue) <- levels(as.factor(info.Abida2019$Sample.Type))
names(pal.path) <- levels(as.factor(info.Abida2019$Pathology.Classification))
breaksList = seq(-2,3, by = 0.1)

pdf("./plots/101Heatmap_Abida_subtypeanno.pdf", width = 7, height = 7)
pheatmap(eSet[gene.sig,order(info.Abida2019$subtype_anno)], 
         scale = "row", clustering_distance_cols = "euclidean",
         clustering_method = "complete",
         show_rownames = T, show_colnames = F,
         fontsize_row = 10, fontsize_col = 1,
         cluster_cols = F, cluster_rows = F,
         annotation_legend = T, border_color = NA,
         color = colorRampPalette(rev(brewer.pal(n = 7, name = "RdYlBu")))(length(breaksList)), # Defines the vector of colors for the legend (it has to be of the same lenght of breaksList)
         breaks = breaksList, annotation_col = annotation_col,
         annotation_colors  = list(
           Subtype = pal.subtype, 
           Tissue = pal.tissue, 
           Pathology = pal.path
         ),
         main = "HRR NE AR"
)
dev.off()


####HRR, AR NE expression levels between subtypes
eSet[AR,]
tmp <- as.data.frame(t(eSet[AR,]))
tmp <- cbind(tmp, info.Abida2019$subtype_num)
colnames(tmp)[length(tmp)] <- "subtype"
pdf("./plots/101Boxplot_AR.pdf", width = 4, height = 4)
for (i in 1:(ncol(tmp)-1)) {
  boxplot(tmp[,i] ~ tmp$subtype, col = pal.subtype, 
          main = colnames(tmp)[i], xlab = "", ylab = "Log2(TPM)")
}
dev.off()

HRR <- intersect(HRR, rownames(eSet))
tmp <- as.data.frame(t(eSet[HRR,]))
tmp <- cbind(tmp, info.Abida2019$subtype_num)
colnames(tmp)[length(tmp)] <- "subtype"
pdf("./plots/101Boxplot_HRR.pdf", width = 4, height = 4)
for (i in 1:(ncol(tmp)-1)) {
  boxplot(tmp[,i] ~ tmp$subtype, col = pal.subtype, 
          main = colnames(tmp)[i], xlab = "", ylab = "Log2(TPM)")
}
dev.off()

NE<- intersect(NE, rownames(eSet))
tmp <- as.data.frame(t(eSet[NE,]))
tmp <- cbind(tmp, info.Abida2019$subtype_num)
colnames(tmp)[length(tmp)] <- "subtype"
pdf("./plots/101Boxplot_NE.pdf", width = 4, height = 4)
for (i in 1:(ncol(tmp)-1)) {
  boxplot(tmp[,i] ~ tmp$subtype, col = pal.subtype, 
          main = colnames(tmp)[i], xlab = "", ylab = "Log2(TPM)")
}
dev.off()

########mutation######## 
library(maftools)
require(data.table)
mutation
colnames(mutation)
load("../PCa_DNAmethy/mutation/maf.PRAD.RData")
maf.filename <- c("Hugo_Symbol", "Entrez_Gene_Id" , "Center", "NCBI_Build","Chromosome" ,  "Start_Position",               
                  "End_Position" ,"Strand", "Variant_Classification" ,"Variant_Type",
                  "Reference_Allele" ,"Tumor_Seq_Allele1" , "Tumor_Seq_Allele2", "dbSNP_RS" ,                    
                 "dbSNP_Val_Status" ,"Tumor_Sample_Barcode" )
tmp <- maf.PRAD
tmp@data <- setDT(mutation[, maf.filename])
Variants <- c(table(mutation$Tumor_Sample_Barcode))
tmp@variants.per.sample <- data.table(Tumor_Sample_Barcode = names(Variants), Variants = Variants)
tmp@clinical.data <- data.table(Tumor_Sample_Barcode = info.Abida2019$Sample.ID, 
                                subtype = info.Abida2019$subtype_num, 
                                tissue = info.Abida2019$Sample.Type,
                                Gleason = info.Abida2019$GGS,
                                stringsAsFactors = T)
pdf("./plots/101MafSumPlot_mCRPC.pdf", width = 6, height = 8)
plotmafSummary(maf = plotmafSummary(maf = tmp, rmOutlier = TRUE, 
                                    addStat = 'median', 
                                    dashboard = TRUE, titvRaw = FALSE), 
               rmOutlier = TRUE, addStat = 'median', 
               dashboard = TRUE, titvRaw = FALSE)
dev.off()

gene.sel <- c(gene.sig, ERG, ETS,"TP53", "TTN", "MUC16", "KMT2C",  "SPTA1", "MUC17", "AHNAK2")
oncoplot(maf = tmp, genes = gene.sel)
col.maf = brewer.pal(n = 10, name = 'Spectral')
names(col.maf) = c("Silent",'Frame_Shift_Del','Missense_Mutation', 'Nonsense_Mutation', 'Multi_Hit', 'Frame_Shift_Ins',
               'In_Frame_Ins', 'Splice_Site', 'In_Frame_Del', "Intron")
col.subtype <- pal.subtype
col.tissue <- pal.tissue
col.ggs <- brewer.pal(7, "Paired")
names(col.subtype) <- c("subtype1", "subtype2", "subtype3", "subtype4")
names(col.tissue) <- unique(info.Abida2019$Sample.Type)
names(col.ggs) <- unique(info.Abida2019$GGS)
annocol = list(subtype = col.subtype, 
              tissue = col.tissue, 
              Gleason = col.ggs)
HRR
mutation.maf <- tmp
#subtype1 == NE , subtype2 == HRR, subtype3 == HRD, subtype4 == AR
pdf("./plots/101Oncoplot_Abida_subtype.pdf", width = 7, height = 6)
oncoplot(maf = mutation.maf, colors = col.maf, clinicalFeatures = c("subtype", "tissue", "Gleason"), 
         sortByAnnotation = T, annotationColor = annocol, top = 25)
oncoplot(maf = mutation.maf, colors = col.maf, clinicalFeatures = c("subtype", "tissue", "Gleason"), 
         sortByAnnotation = T, annotationColor = annocol, genes = gene.sig)
oncoplot(maf = mutation.maf, colors = col.maf, clinicalFeatures = c("subtype", "tissue", "Gleason"), 
         sortByAnnotation = T, annotationColor = annocol, genes = AR)
oncoplot(maf = mutation.maf, colors = col.maf, clinicalFeatures = c("subtype", "tissue", "Gleason"), 
         sortByAnnotation = T, annotationColor = annocol, genes = HRR)
oncoplot(maf = mutation.maf, colors = col.maf, clinicalFeatures = c("subtype", "tissue", "Gleason"), 
         sortByAnnotation = T, annotationColor = annocol, genes = NE)
dev.off()

info.Abida2019$subtype <- info.Abida2019$subtype_num

save(eSet, info.Abida2019, mutation, mutation.maf,
     file = "./101multiOmic_subtype.RData")


####mutation with gene expression ######
load(file = "./101multiOmic_subtype.RData")

#BRCA1
idx.mut <- mutation[grep("BRCA1", mutation$Hugo_Symbol), "Tumor_Sample_Barcode"]
keep <- intersect(colnames(eSet) ,  idx.mut)
info.Abida2019$BRCA1mut <- "wildtype"
info.Abida2019$BRCA1mut[which(colnames(eSet) %in% keep) ] <- "mutant"
tmp <- cbind(eSet["BRCA1" ,c(which(colnames(eSet) %in% keep), which(!(colnames(eSet) %in% keep)))], info.Abida2019$BRCA1mut)
colnames(tmp) <- c("gene", "mutation")
tmp <- as.data.frame(tmp)
tmp$gene <- as.numeric(as.character(tmp$gene))
tmp$mutation <- as.character(tmp$mutation)
wilcox.test(gene ~ mutation  , data = tmp)
png("./plots/101Boxplot_mutation_BRCA1.png", width = 4, height = 4, units = "in", res = 300)
boxplot(gene ~ mutation  , data = tmp,  col=pal.mut, 
        ylab = c("log(TPM)"), xlab = c("Wilcoxon test, p = 0.4116"), 
        main = c("BRCA1"))
dev.off()
#BRCA2
idx.mut <- mutation[grep("BRCA2", mutation$Hugo_Symbol), "Tumor_Sample_Barcode"]
keep <- intersect(colnames(eSet) ,  idx.mut)
info.Abida2019$BRCA1mut <- "wildtype"
info.Abida2019$BRCA1mut[which(colnames(eSet) %in% keep) ] <- "mutant"
tmp <- cbind(eSet["BRCA2" ,c(which(colnames(eSet) %in% keep), which(!(colnames(eSet) %in% keep)))], info.Abida2019$BRCA1mut)
colnames(tmp) <- c("gene", "mutation")
tmp <- as.data.frame(tmp)
tmp$gene <- as.numeric(as.character(tmp$gene))
tmp$mutation <- as.character(tmp$mutation)
wilcox.test(gene ~ mutation  , data = tmp)
png("./plots/101Boxplot_mutation_BRCA2.png", width = 4, height = 4, units = "in", res = 300)
boxplot(gene ~ mutation  , data = tmp,  col=pal.mut, 
        ylab = c("log(TPM)"), xlab = c("Wilcoxon test, p = 0.9662"), 
        main = c("BRCA2"))
dev.off()
#ATM
idx.mut <- mutation[grep("ATM", mutation$Hugo_Symbol), "Tumor_Sample_Barcode"]
keep <- intersect(colnames(eSet) ,  idx.mut)
info.Abida2019$BRCA1mut <- "wildtype"
info.Abida2019$BRCA1mut[which(colnames(eSet) %in% keep) ] <- "mutant"
tmp <- cbind(eSet["ATM" ,c(which(colnames(eSet) %in% keep), which(!(colnames(eSet) %in% keep)))], info.Abida2019$BRCA1mut)
colnames(tmp) <- c("gene", "mutation")
tmp <- as.data.frame(tmp)
tmp$gene <- as.numeric(as.character(tmp$gene))
tmp$mutation <- as.character(tmp$mutation)
wilcox.test(gene ~ mutation  , data = tmp)
png("./plots/101Boxplot_mutation_ATM.png", width = 4, height = 4, units = "in", res = 300)
boxplot(gene ~ mutation  , data = tmp,  col=pal.mut, 
        ylab = c("log(TPM)"), xlab = c("Wilcoxon test, p = 0.8401"), 
        main = c("ATM"))
dev.off()



####survival#######
info.Abida2019
survival.df <- read.csv("./datasets/prad_su2c_2019/survival.csv", header = T, stringsAsFactors = F)
survival.df$Subject.ID <- as.character(survival.df$Subject.ID)
info.Abida2019$Taxane.exposure.status
info.Abida2019$Abiraterone..ABI..and.Enzalutamide..ENZA..Exposure.Status 
info.Abida2019$Subject.ID <- as.character(info.Abida2019$Subject.ID)
survival.df[match(info.Abida2019$Subject.ID, survival.df$Subject.ID),c(3,4)]
info.Abida2019 <- cbind(info.Abida2019, survival.df[match(info.Abida2019$Subject.ID, survival.df$Subject.ID),])

library(survival)
library("survminer")

my.surv <- Surv(info.Abida2019$OS.from.first.line.ARSI.start,info.Abida2019$Death.status==1)
kmfit1 <- survfit(my.surv~subtype,data = info.Abida2019) 
survdiff(Surv(OS.from.first.line.ARSI.start, Death.status) ~ subtype,data=info.Abida2019)

#subtype1 == Basal , subtype2 == HRR, subtype3 == NE, subtype4 == Luminal
#all sample
pdf("./plots/101KMplot_Abida2019_subtype.pdf", width = 6, height = 7)
plot(kmfit1,col = pal.subtype, 
     main = "Overall Survival", 
     xlab = "Months", 
     ylab = "Cumulative Survival Rate")
legend("bottomleft", legend = c("subtype1", "subtype2", "subtype3", "subtype4"), 
       col = pal.subtype, lty = c(1,1), cex = 0.75)

ggsurvplot(kmfit1, pval = T, conf.int = F,
           risk.table = TRUE, # Add risk table
           risk.table.col = "strata", # Change risk table color by groups
           #linetype = "strata", # Change line type by groups
           #surv.median.line = "hv", # Specify median survival
           ggtheme = theme_bw(), # Change ggplot2 theme
           palette = pal.subtype)
dev.off()

#subdivide by ARSI 
pal.ARSI <- brewer.pal(3, "Dark2")
idx.sub <- grep("subtype1", info.Abida2019$subtype)
my.surv <- Surv(info.Abida2019[idx.sub,]$OS.from.first.line.ARSI.start, info.Abida2019[idx.sub,]$Death.status==1)
kmfit1 <- survfit(my.surv~Abiraterone..ABI..and.Enzalutamide..ENZA..Exposure.Status,data = info.Abida2019[idx.sub,]) 
survdiff(Surv(OS.from.first.line.ARSI.start, Death.status) ~ Abiraterone..ABI..and.Enzalutamide..ENZA..Exposure.Status,data=info.Abida2019[idx.sub,])
ggsurvplot(kmfit1, pval = T, conf.int = F,
           risk.table = TRUE, # Add risk table
           risk.table.col = "strata", # Change risk table color by groups
           #linetype = "strata", # Change line type by groups
           #surv.median.line = "hv", # Specify median survival
           ggtheme = theme_bw(), # Change ggplot2 theme
           palette = pal.ARSI)

idx.sub <- grep("subtype4", info.Abida2019$subtype)
my.surv <- Surv(info.Abida2019[idx.sub,]$OS.from.first.line.ARSI.start, info.Abida2019[idx.sub,]$Death.status==1)
kmfit1 <- survfit(my.surv~Abiraterone..ABI..and.Enzalutamide..ENZA..Exposure.Status,data = info.Abida2019[idx.sub,]) 
survdiff(Surv(OS.from.first.line.ARSI.start, Death.status) ~ Abiraterone..ABI..and.Enzalutamide..ENZA..Exposure.Status,data=info.Abida2019[idx.sub,])
ggsurvplot(kmfit1, pval = T, conf.int = F,
           risk.table = TRUE, # Add risk table
           risk.table.col = "strata", # Change risk table color by groups
           #linetype = "strata", # Change line type by groups
           #surv.median.line = "hv", # Specify median survival
           ggtheme = theme_bw(), # Change ggplot2 theme
           palette = pal.ARSI)

idx.sub <- grep("Exposed", info.Abida2019$Abiraterone..ABI..and.Enzalutamide..ENZA..Exposure.Status)
my.surv <- Surv(info.Abida2019[idx.sub,]$OS.from.first.line.ARSI.start, info.Abida2019[idx.sub,]$Death.status==1)
kmfit1 <- survfit(my.surv~ subtype, data = info.Abida2019[idx.sub,]) 
survdiff(Surv(OS.from.first.line.ARSI.start, Death.status) ~ subtype,data=info.Abida2019[idx.sub,])
ggsurvplot(kmfit1, pval = T, conf.int = F,
           risk.table = TRUE, # Add risk table
           risk.table.col = "strata", # Change risk table color by groups
           #linetype = "strata", # Change line type by groups
           #surv.median.line = "hv", # Specify median survival
           ggtheme = theme_bw(), # Change ggplot2 theme
           palette = pal.subtype)



info.Abida2019$subtype <- info.Abida2019$subtype_num
pal.ARSI <- brewer.pal(3, "Dark2")
tmp <- info.Abida2019[grep("subtype1", info.Abida2019$subtype),]
my.surv <- Surv(tmp$OS.from.first.line.ARSI.start,tmp$Death.status==1)
kmfit1 <- survfit(my.surv ~ Abiraterone..ABI..and.Enzalutamide..ENZA..Exposure.Status,data = tmp) 
survdiff(Surv(OS.from.first.line.ARSI.start, Death.status) ~ Abiraterone..ABI..and.Enzalutamide..ENZA..Exposure.Status,data=tmp)

ggsurvplot(kmfit1, pval = T, conf.int = F,
           risk.table = TRUE, # Add risk table
           risk.table.col = "strata", # Change risk table color by groups
           #linetype = "strata", # Change line type by groups
           #surv.median.line = "hv", # Specify median survival
           ggtheme = theme_bw(), # Change ggplot2 theme
           palette = pal.ARSI)
####
table(info.Abida2019$subtype)


pal.ARSI <- brewer.pal(3, "Dark2")
tmp <- info.Abida2019[grep("AR", info.Abida2019$subtype),]
my.surv <- Surv(tmp$OS.from.first.line.ARSI.start,tmp$Death.status==1)
kmfit1 <- survfit(my.surv ~ Taxane.exposure.status,data = tmp) 
survdiff(Surv(OS.from.first.line.ARSI.start, Death.status) ~ Taxane.exposure.status,data=tmp)

ggsurvplot(kmfit1, pval = T, conf.int = F,
           risk.table = TRUE, # Add risk table
           risk.table.col = "strata", # Change risk table color by groups
           #linetype = "strata", # Change line type by groups
           #surv.median.line = "hv", # Specify median survival
           ggtheme = theme_bw(), # Change ggplot2 theme
           palette = pal.ARSI)
####



######eSet for GSEA######
eSet.tmp <- eSet[,c(grep("subtype1", info.Abida2019$subtype_num), grep("subtype1", info.Abida2019$subtype_num, invert = T))]
colnames(eSet.tmp) <- c(paste0("Basal",1:length(grep("subtype1", info.Abida2019$subtype_num))),  paste0("nonBasal",1:length(grep("subtype1", info.Abida2019$subtype_num, invert = T))))
write.csv(eSet.tmp, file = "./101GSEA_Basal.csv", row.names = T)

eSet.tmp <- eSet[,c(grep("subtype2", info.Abida2019$subtype_num), grep("subtype2", info.Abida2019$subtype_num, invert = T))]
colnames(eSet.tmp) <- c(paste0("HRR",1:length(grep("subtype2", info.Abida2019$subtype_num))),  paste0("nonHRR",1:length(grep("subtype2", info.Abida2019$subtype_num, invert = T))))
write.csv(eSet.tmp, file = "./101GSEA_HRR.csv", row.names = T)

eSet.tmp <- eSet[,c(grep("subtype3", info.Abida2019$subtype_num), grep("subtype3", info.Abida2019$subtype_num, invert = T))]
colnames(eSet.tmp) <- c(paste0("NE",1:length(grep("subtype3", info.Abida2019$subtype_num))),  paste0("nonNE",1:length(grep("subtype3", info.Abida2019$subtype_num, invert = T))))
write.csv(eSet.tmp, file = "./101GSEA_NE.csv", row.names = T)

eSet.tmp <- eSet[,c(grep("subtype4", info.Abida2019$subtype_num), grep("subtype4", info.Abida2019$subtype_num, invert = T))]
colnames(eSet.tmp) <- c(paste0("HRR",1:length(grep("subtype4", info.Abida2019$subtype_num))),  paste0("nonLuminal",1:length(grep("subtype4", info.Abida2019$subtype_num, invert = T))))
write.csv(eSet.tmp, file = "./101GSEA_Luminal.csv", row.names = T)



