load(file = "./101multiOmic_subtype.RData")
library(limma)
library(RColorBrewer)
pal.subtype <- brewer.pal(4, "Set1")
pal.path <- brewer.pal(5, "Paired")
pal.tissue <- brewer.pal(7, "Set2")


info.Abida2019$subtype_anno <- NA
info.Abida2019$subtype_anno[which(info.Abida2019$subtype_num =="subtype1")] <- "Basal"
info.Abida2019$subtype_anno[which(info.Abida2019$subtype_num =="subtype2")] <- "HRR"
info.Abida2019$subtype_anno[which(info.Abida2019$subtype_num =="subtype3")] <- "NE"
info.Abida2019$subtype_anno[which(info.Abida2019$subtype_num =="subtype4")] <- "Luminal"
table(info.Abida2019$subtype_anno, info.Abida2019$Sample.Type)



#PCA
pdf("./plots/102PCA_Abida_subtype.pdf", width = 5, height = 5)
plotMDS(eSet, top = 1000, pch = 19, gene.selection = "common", 
        col=pal.subtype[factor(info.Abida2019$subtype)], cex = 1)
legend("topright", legend=levels(factor(info.Abida2019$subtype)), text.col=pal.subtype,
       bg="white", cex=1)
dev.off()


#tSNE
library(caret)  
library(Rtsne)
##Rtsne function
set.seed(9)
tsne_model1 <- Rtsne(t(eSet), check_duplicates = F, pca = T, perplexity = 50, theta = 0.5, dims = 2)

## getting the two dimension matrix
d_tsne_1 <- as.data.frame(tsne_model1$Y)
d_tsne_1 <- cbind(d_tsne_1, info.Abida2019[,"subtype"])
colnames(d_tsne_1)[3] <- "subtype"

## plotting the results without clustering
png("./plots/102tSNE_subtype.png", width = 5.5, height = 5, units = "in", res = 300)
ggplot(d_tsne_1, aes(x = V1, y = V2, colour = subtype))+
  geom_point(size = 4)+
  guides(colour=guide_legend(override.aes=list(size=1))) +
  xlab("") + ylab("") +
  ggtitle("t-SNE") +
  theme_classic(base_size=20) +
  theme(axis.text.x=element_blank(),
        axis.text.y=element_blank()) +
  scale_colour_brewer(palette = "Set1")
dev.off()



####limma#########
cellType <- factor(info.Abida2019$subtype_anno)
table(cellType)

design <- model.matrix(~0+cellType, data=info.Abida2019)
colnames(design) <- c(levels(cellType))
v <- voom(eSet, design, plot=TRUE)
v
fit <- lmFit(v, design)
contMatrix <- makeContrasts(Basal-HRR,
                            Basal-Luminal,
                            Basal-NE,
                            #subtype1-subtype5,
                            #subtype2-subtype1,
                            HRR-Luminal,
                            HRR-NE,
                            #subtype2-subtype5,
                            #subtype3-subtype2,
                            #subtype3-subtype1,
                            Luminal-NE,
                            #subtype3-subtype5,
                            #subtype4-subtype2,
                            #subtype4-subtype3,
                            #subtype4-subtype1,
                            #subtype4-subtype5,
                            #subtype5-subtype2,
                            #subtype5-subtype3,
                            #subtype5-subtype1,
                            #subtype5-subtype4,
                            levels=design)
contMatrix

fit2 <- contrasts.fit(fit, contMatrix)
fit2 <- eBayes(fit2)

summary(decideTests(fit2))

#Basal
DEG1 <- topTable(fit2, num=Inf, coef=1)
DEG1 <- DEG1[which(abs(DEG1$logFC) >2 & DEG1$adj.P.Val <0.01),]
DEG1 <- rownames(DEG1)
DEG2 <- topTable(fit2, num=Inf, coef=2)
DEG2 <- DEG2[which(abs(DEG2$logFC) >2 & DEG2$adj.P.Val <0.01),]
DEG2 <- rownames(DEG2)
DEG3 <- topTable(fit2, num=Inf, coef=3)
DEG3 <- DEG3[which(abs(DEG3$logFC) >2 & DEG3$adj.P.Val <0.01),]
DEG3 <- rownames(DEG3)
DEG_Basal <- c(DEG1, DEG3, DEG2)
#HRR
DEG1 <- topTable(fit2, num=Inf, coef=1)
DEG1 <- DEG1[which(abs(DEG1$logFC) >2 & DEG1$adj.P.Val <0.01),]
DEG1 <- rownames(DEG1)
DEG2 <- topTable(fit2, num=Inf, coef=4)
DEG2 <- DEG2[which(abs(DEG2$logFC) >2 & DEG2$adj.P.Val <0.01),]
DEG2 <- rownames(DEG2)
DEG3 <- topTable(fit2, num=Inf, coef=5)
DEG3 <- DEG3[which(abs(DEG3$logFC) >2 & DEG3$adj.P.Val <0.01),]
DEG3 <- rownames(DEG3)
DEG_HRR <- c(DEG1, DEG2, DEG3)
#Luminal
DEG1 <- topTable(fit2, num=Inf, coef=2)
DEG1 <- DEG1[which(abs(DEG1$logFC) >2 & DEG1$adj.P.Val <0.01),]
DEG1 <- rownames(DEG1)
DEG2 <- topTable(fit2, num=Inf, coef=4)
DEG2 <- DEG2[which(abs(DEG2$logFC) >2 & DEG2$adj.P.Val <0.01),]
DEG2 <- rownames(DEG2)
DEG3 <- topTable(fit2, num=Inf, coef=6)
DEG3 <- DEG3[which(abs(DEG3$logFC) >2 & DEG3$adj.P.Val <0.01),]
DEG3 <- rownames(DEG3)
DEG_Luminal <- c(DEG1, DEG2, DEG3)
#NE
DEG1 <- topTable(fit2, num=Inf, coef=3)
DEG1 <- DEG1[which(abs(DEG1$logFC) >2 & DEG1$adj.P.Val <0.01),]
DEG1 <- rownames(DEG1)
DEG2 <- topTable(fit2, num=Inf, coef=5)
DEG2 <- DEG2[which(abs(DEG2$logFC) >2 & DEG2$adj.P.Val <0.01),]
DEG2 <- rownames(DEG2)
DEG3 <- topTable(fit2, num=Inf, coef=6)
DEG3 <- DEG3[which(abs(DEG3$logFC) >2 & DEG3$adj.P.Val <0.01),]
DEG3 <- rownames(DEG3)
DEG_NE <- intersect(DEG1, DEG2)
gene.sig <- unique(c(DEG_Basal, DEG_HRR, DEG_NE,DEG_Luminal))

library(pheatmap)
annotation_col = data.frame(
  Subtype = info.Abida2019$subtype_num, 
  Tissue = info.Abida2019$Sample.Type,
  Pathology = info.Abida2019$Pathology.Classification
)
rownames(annotation_col) = colnames(eSet)
names(pal.subtype) <- levels(as.factor(info.Abida2019$subtype_num))
names(pal.tissue) <- levels(as.factor(info.Abida2019$Sample.Type))
names(pal.path) <- levels(as.factor(info.Abida2019$Pathology.Classification))
breaksList = seq(-0.8,0.8, by = 0.01)

pdf("./plots/102Heatmap_Abida_limma.pdf", width = 7, height = 7)
pheatmap(scale(eSet[gene.sig,order(info.Abida2019$subtype_num)]), 
         scale = "row", clustering_distance_cols = "euclidean",
         clustering_method = "complete",
         show_rownames = F, show_colnames = F,
         fontsize_row = 5, fontsize_col = 1,
         cluster_cols = F, cluster_rows = T,
         annotation_legend = T, border_color = NA,
         color = colorRampPalette(rev(brewer.pal(n = 7, name = "RdYlBu")))(length(breaksList)), # Defines the vector of colors for the legend (it has to be of the same lenght of breaksList)
         breaks = breaksList, 
         annotation_col = annotation_col,
         annotation_colors  = list(
           Subtype = pal.subtype, 
           Tissue = pal.tissue, 
           Pathology = pal.path
         ),
         main = "HRR NE AR"
)
dev.off()

write.csv(data.frame(gene.sig), file = "./genesig_limma.csv")



########SAM######
library(samr)
y <- as.numeric(gsub("subtype", "", info.Abida2019$subtype_num))
x <- scale(eSet)
head(eSet[1:4,1:5])
head(x[1:4,1:5])
set.seed(84048)
sam.out <- SAM(x,y,resp.type="Multiclass",nperms=50)
which(as.numeric(sam.out$siggenes.table[["genes.up"]][,10]) < 0.001)

genesig.sam <- rownames(eSet)[which(as.numeric(sam.out$siggenes.table[["genes.up"]][,10]) < 0.001)]
save(genesig.sam, file = "./genesig_sam.rds")



library(pheatmap)
annotation_col = data.frame(
  Subtype = info.Abida2019$subtype_num, 
  Tissue = info.Abida2019$Sample.Type,
  Pathology = info.Abida2019$Pathology.Classification
)
rownames(annotation_col) = colnames(x)
names(pal.subtype) <- levels(as.factor(info.Abida2019$subtype_num))
names(pal.tissue) <- levels(as.factor(info.Abida2019$Sample.Type))
names(pal.path) <- levels(as.factor(info.Abida2019$Pathology.Classification))
breaksList = seq(-1,1, by = 0.1)

pdf("./plots/102Heatmap_Abida_SAM.pdf", width = 7, height = 7)
pheatmap(x[genesig.sam,order(info.Abida2019$subtype_num)], 
         scale = "row", clustering_distance_cols = "euclidean",
         clustering_method = "complete",
         show_rownames = F, show_colnames = F,
         fontsize_row = 10, fontsize_col = 1,
         cluster_cols = F, cluster_rows = T,
         annotation_legend = T, border_color = NA,
         color = colorRampPalette(rev(brewer.pal(n = 7, name = "RdYlBu")))(length(breaksList)), # Defines the vector of colors for the legend (it has to be of the same lenght of breaksList)
         breaks = breaksList, 
         annotation_col = annotation_col,
         annotation_colors  = list(
           Subtype = pal.subtype, 
           Tissue = pal.tissue, 
           Pathology = pal.path
         ),
         main = "HRR NE AR"
)
dev.off()



x=matrix(rnorm(1000*10),ncol=10)
y=c(rep(1,3),rep(2,3),rep(3,4))
x[1:50,y==3]=x[1:50,y==3]+5
a <- SAM(x,y,resp.type="Multiclass",nperms=50)




#########GO##########
write.csv(data.frame(genesig.sam), file = "./genesig_SAM.csv")


