load(file = "./101multiOmic_subtype.RData")
library(limma)
library(RColorBrewer)
pal.subtype <- brewer.pal(4, "Set1")
pal.path <- brewer.pal(5, "Paired")
pal.tissue <- brewer.pal(7, "Set2")


library(MCPcounter)
#ExampleEstimates=MCPcounter.estimate(MCPcounterExampleData,featuresType="affy133P2_probesets")
MCP.out <- MCPcounter.estimate(eSet,featuresType="HUGO_symbols")
MCP.out <- as.matrix(MCP.out)
rownames(MCP.out)
info.Abida2019 <- cbind(info.Abida2019, as.data.frame(t(MCP.out)))

save(eSet, info.Abida2019, mutation, mutation.maf, 
     file = "./101multiOmic_subtype.RData")

### heatmap
library(pheatmap)
annotation_col = data.frame(
  Subtype = info.Abida2019$subtype_num, 
  Tissue = info.Abida2019$Sample.Type,
  Pathology = info.Abida2019$Pathology.Classification
)
rownames(annotation_col) = colnames(eSet)
order(info.Abida2019$subtype)

names(pal.subtype) <- levels(as.factor(info.Abida2019$subtype_num))
names(pal.tissue) <- levels(as.factor(info.Abida2019$Sample.Type))
names(pal.path) <- levels(as.factor(info.Abida2019$Pathology.Classification))
breaksList = seq(-2 ,3, by = 0.1)

pdf("./plots/104Heatmap_Abida_MCPcount.pdf", width = 7, height = 5)
pheatmap(MCP.out[, order(info.Abida2019$subtype_num)] , 
         scale = "row", clustering_distance_cols = "euclidean",
         clustering_method = "complete",
         show_rownames = T, show_colnames = F,
         fontsize_row = 10, fontsize_col = 1,
         cluster_cols = F, cluster_rows = F,
         annotation_legend = T, border_color = NA,
         color = colorRampPalette(rev(brewer.pal(n = 7, name = "RdYlBu")))(length(breaksList)), # Defines the vector of colors for the legend (it has to be of the same lenght of breaksList)
         breaks = breaksList, 
         annotation_col = annotation_col,
         annotation_colors  = list(
           Subtype = pal.subtype, 
           Tissue = pal.tissue, 
           Pathology = pal.path
         ),
         main = "Immune Cells"
)
dev.off()



### immune checkpoint genes#####
grep("CD274", rownames(eSet), value = T)
checkpoint <- c("CD274", "PDCD1LG2", "CTLA4", "VTCN1", "VSIR", "LAG3", "IDO1", 
                "IDO2", "HAVCR1")
eSet <- as.data.frame(eSet)
eSet[checkpoint,]

violin.df <- cbind(as.data.frame(t(eSet[checkpoint,])), info.Abida2019$subtype_num)
colnames(violin.df)[ncol(violin.df)]  <- "subtype"

library(ggplot2)
pdf("./plots/104Violinplot_checkpoint.pdf", width = 5, height = 5)
pvalue <- summary(aov(CD274 ~ subtype, data = violin.df))[[1]][["Pr(>F)"]][[1]]
TukeyHSD(aov(CD274 ~ subtype, data = violin.df))
ggplot(data = violin.df, aes(x = subtype, y = CD274))+
  geom_violin(aes(fill = factor(subtype)))+
  geom_boxplot(width = 0.3, outlier.size = -1)+
  geom_jitter(height = 0.002, width = 0.2, cex = 1.2)+
  scale_fill_brewer(palette="Set1")+
  labs(y = "CD274", 
       x = paste0("ANOVA: p=", round(pvalue, 6)), 
       title = "")+ 
  #ylim(0,1)+
  #theme_bw()+ 
  theme_classic()+
  theme(legend.position = "none") 

pvalue <- summary(aov(PDCD1LG2 ~ subtype, data = violin.df))[[1]][["Pr(>F)"]][[1]]
TukeyHSD(aov(PDCD1LG2 ~ subtype, data = violin.df))
ggplot(data = violin.df, aes(x = subtype, y = PDCD1LG2))+
  geom_violin(aes(fill = factor(subtype)))+
  geom_boxplot(width = 0.3, outlier.size = -1)+
  geom_jitter(height = 0.002, width = 0.2, cex = 1.2)+
  scale_fill_brewer(palette="Set1")+
  labs(y = "PDCD1LG2", 
       x = paste0("ANOVA: p=", round(pvalue, 6)), 
       title = "")+ 
  #ylim(0,1)+
  #theme_bw()+ 
  theme_classic()+
  theme(legend.position = "none") 

pvalue <- summary(aov(CTLA4 ~ subtype, data = violin.df))[[1]][["Pr(>F)"]][[1]]
TukeyHSD(aov(CTLA4 ~ subtype, data = violin.df))
ggplot(data = violin.df, aes(x = subtype, y = CTLA4))+
  geom_violin(aes(fill = factor(subtype)))+
  geom_boxplot(width = 0.3, outlier.size = -1)+
  geom_jitter(height = 0.002, width = 0.2, cex = 1.2)+
  scale_fill_brewer(palette="Set1")+
  labs(y = "CTLA4", 
       x = paste0("ANOVA: p=", round(pvalue, 6)), 
       title = "")+ 
  #ylim(0,1)+
  #theme_bw()+ 
  theme_classic()+
  theme(legend.position = "none") 


pvalue <- summary(aov(VTCN1 ~ subtype, data = violin.df))[[1]][["Pr(>F)"]][[1]]
TukeyHSD(aov(VTCN1 ~ subtype, data = violin.df))
ggplot(data = violin.df, aes(x = subtype, y = VTCN1))+
  geom_violin(aes(fill = factor(subtype)))+
  geom_boxplot(width = 0.3, outlier.size = -1)+
  geom_jitter(height = 0.002, width = 0.2, cex = 1.2)+
  scale_fill_brewer(palette="Set1")+
  labs(y = "VTCN1", 
       x = paste0("ANOVA: p=", round(pvalue, 6)), 
       title = "")+ 
  #ylim(0,1)+
  #theme_bw()+ 
  theme_classic()+
  theme(legend.position = "none") 

pvalue <- summary(aov(VSIR ~ subtype, data = violin.df))[[1]][["Pr(>F)"]][[1]]
TukeyHSD(aov(VSIR ~ subtype, data = violin.df))
ggplot(data = violin.df, aes(x = subtype, y = VSIR))+
  geom_violin(aes(fill = factor(subtype)))+
  geom_boxplot(width = 0.3, outlier.size = -1)+
  geom_jitter(height = 0.002, width = 0.2, cex = 1.2)+
  scale_fill_brewer(palette="Set1")+
  labs(y = "VSIR", 
       x = paste0("ANOVA: p=", round(pvalue, 6)), 
       title = "")+ 
  #ylim(0,1)+
  #theme_bw()+ 
  theme_classic()+
  theme(legend.position = "none") 

pvalue <- summary(aov(LAG3 ~ subtype, data = violin.df))[[1]][["Pr(>F)"]][[1]]
TukeyHSD(aov(LAG3 ~ subtype, data = violin.df))
ggplot(data = violin.df, aes(x = subtype, y = LAG3))+
  geom_violin(aes(fill = factor(subtype)))+
  geom_boxplot(width = 0.3, outlier.size = -1)+
  geom_jitter(height = 0.002, width = 0.2, cex = 1.2)+
  scale_fill_brewer(palette="Set1")+
  labs(y = "LAG3", 
       x = paste0("ANOVA: p=", round(pvalue, 6)), 
       title = "")+ 
  #ylim(0,1)+
  #theme_bw()+ 
  theme_classic()+
  theme(legend.position = "none") 

pvalue <- summary(aov(IDO1 ~ subtype, data = violin.df))[[1]][["Pr(>F)"]][[1]]
TukeyHSD(aov(IDO1 ~ subtype, data = violin.df))
ggplot(data = violin.df, aes(x = subtype, y = IDO1))+
  geom_violin(aes(fill = factor(subtype)))+
  geom_boxplot(width = 0.3, outlier.size = -1)+
  geom_jitter(height = 0.002, width = 0.2, cex = 1.2)+
  scale_fill_brewer(palette="Set1")+
  labs(y = "IDO1", 
       x = paste0("ANOVA: p=", round(pvalue, 6)), 
       title = "")+ 
  #ylim(0,1)+
  #theme_bw()+ 
  theme_classic()+
  theme(legend.position = "none") 

pvalue <- summary(aov(IDO2 ~ subtype, data = violin.df))[[1]][["Pr(>F)"]][[1]]
TukeyHSD(aov(IDO2 ~ subtype, data = violin.df))
ggplot(data = violin.df, aes(x = subtype, y = IDO2))+
  geom_violin(aes(fill = factor(subtype)))+
  geom_boxplot(width = 0.3, outlier.size = -1)+
  geom_jitter(height = 0.002, width = 0.2, cex = 1.2)+
  scale_fill_brewer(palette="Set1")+
  labs(y = "IDO2", 
       x = paste0("ANOVA: p=", round(pvalue, 6)), 
       title = "")+ 
  #ylim(0,1)+
  #theme_bw()+ 
  theme_classic()+
  theme(legend.position = "none") 

pvalue <- summary(aov(HAVCR1 ~ subtype, data = violin.df))[[1]][["Pr(>F)"]][[1]]
TukeyHSD(aov(HAVCR1 ~ subtype, data = violin.df))
ggplot(data = violin.df, aes(x = subtype, y = HAVCR1))+
  geom_violin(aes(fill = factor(subtype)))+
  geom_boxplot(width = 0.3, outlier.size = -1)+
  geom_jitter(height = 0.002, width = 0.2, cex = 1.2)+
  scale_fill_brewer(palette="Set1")+
  labs(y = "HAVCR1", 
       x = paste0("ANOVA: p=", round(pvalue, 6)), 
       title = "")+ 
  #ylim(0,1)+
  #theme_bw()+ 
  theme_classic()+
  theme(legend.position = "none") 

dev.off()





#### HLA ######
HLAgene <- grep("HLA-", rownames(eSet), value = T)
eSet <- as.data.frame(eSet)
eSet[HLAgene,]

violin.df <- cbind(as.data.frame(t(eSet[HLAgene,])), info.Abida2019$subtype_num)
colnames(violin.df)[ncol(violin.df)]  <- "subtype"
colnames(violin.df) <- gsub("-", "_", colnames(violin.df))

library(ggplot2)
pdf("./plots/104Violinplot_HLA.pdf", width = 5, height = 5)
for (i in 1:(ncol(violin.df)-1)) {
  print(colnames(violin.df)[i])
  pvalue <- summary(aov(violin.df[,i]~violin.df[,ncol(violin.df)]))[[1]][["Pr(>F)"]][[1]]
  TukeyHSD(aov(violin.df[,i]~violin.df[,ncol(violin.df)]))
  print(ggplot(data = violin.df, aes(x = subtype, y = violin.df[,i]))+
    geom_violin(aes(fill = factor(subtype)))+
    geom_boxplot(width = 0.3, outlier.size = -1)+
    geom_jitter(height = 0.002, width = 0.2, cex = 1.2)+
    scale_fill_brewer(palette="Set1")+
    labs(y = paste0( gsub("_", "-", colnames(violin.df)[i]), "  log2(TPM)"), 
         x = paste0("ANOVA: p=", round(pvalue, 6)), 
         title = "")+ 
    #ylim(0,1)+
    #theme_bw()+ 
    theme_classic()+
    theme(legend.position = "none") 
  )
}
dev.off()

