load(file = "./101multiOmic_subtype.RData")
info.Abida2019$subtype_anno <- "Luminal"
info.Abida2019[grep("subtype1", info.Abida2019$subtype_num),] <- "Basal"
info.Abida2019[grep("subtype2", info.Abida2019$subtype_num),] <- "HRR"
info.Abida2019[grep("subtype3", info.Abida2019$subtype_num),] <- "NE"
library(limma)
library(RColorBrewer)
pal.subtype <- brewer.pal(4, "Set1")
pal.path <- brewer.pal(5, "Paired")
pal.tissue <- brewer.pal(7, "Set2")


###RF feature########
#Do not need to re-run, using load files
library(randomForest)
set.seed(1)
RF.df <- as.data.frame(t(eSet))
colnames(RF.df) <- gsub("-", "_", colnames(RF.df))

set.seed(40)
idx.set <- sample(1:2, ncol(RF.df), replace=T) 
cg<-c()
for (j in 1:2) {
  traindata.set <- RF.df[,idx.set == j]
  print(paste0("-----", "training set:",j,"------"))
  traindata.set <- cbind(traindata.set, info.Abida2019$subtype) #traindata , so idx == 1
  colnames(traindata.set)[ncol(traindata.set)] <- "subtype"
  
  for (k in 1:100) {
  print(paste0("-----", "RF model:",k,"------"))
  set.seed(k) # RF model to shortlist the cg candidates
  blood_rf <- randomForest(subtype ~ ., data = traindata.set, ntree = 100, proximity = T)
  tmp <- as.data.frame(importance(blood_rf))
  tmp$name <- rownames(tmp)
  tmp <- tmp$name[order(tmp[,1], decreasing = T)] #finding the most importance cg
  tmp <- tmp[1:5] # top 250 cg
  cg <- c(cg, tmp) 
  cg <- unique(cg) 
  print(length(cg))# overlapping cg
  }
save(cg, file = paste0("./RF_",j, ".rds"))
}

load("./RF_1.rds")
load("./RF_2.rds")# RF_2 is the final feature

gene.sig <- cg  
gene.sig[4] <- "SEPT4"
gene.sig <- gene.sig[-c(grep("VSIR", gene.sig))]


####RF model######
colnames(RF.df) <- gsub("Sep_04", "SEPT4", colnames(RF.df))
set.seed(156)
idx.set <- sample(seq_len(nrow(RF.df)), size = floor(0.40 * nrow(RF.df)))
traindata.set <- RF.df[idx.set, gene.sig ]
test.set <- RF.df[which(!rownames(RF.df) %in% rownames(traindata.set) ) , gene.sig]
traindata.set <- cbind(traindata.set, info.Abida2019$subtype_anno[idx.set]) #traindata , so idx == 1
colnames(traindata.set)[ncol(traindata.set)] <- "subtype"
set.seed(3227)
blood_rf <- randomForest(subtype ~ ., data = traindata.set, ntree = 100, proximity = T, importance = T)
traindata_pred <- predict(blood_rf, newdata = traindata.set[,1:ncol(traindata.set)-1])
table(traindata_pred, traindata.set$subtype)
test_pred <- predict(blood_rf, newdata = test.set)
table(test_pred, info.Abida2019$subtype_anno[which(!rownames(RF.df) %in% rownames(traindata.set) )])


#SAM
load(file = "./genesig_sam.rds")
RF.df <- as.data.frame(t(eSet[genesig.sam,]))
RF.df <- cbind(RF.df, info.Abida2019$subtype_anno) #traindata , so idx == 1
colnames(RF.df)[ncol(RF.df)] <- "subtype"
set.seed(3227)
blood_rf <- randomForest(subtype ~ ., data = RF.df, ntree = 100, proximity = T, importance = T)
grep("AATK-AS1", colnames(RF.df))
grep("AATK-AS1", genesig.sam)

#limma 
gene.sig <- read.csv("./genesig_limma.csv", header = T, stringsAsFactors = F)
gene.sig <- gene.sig$gene.sig


##### prediction matrix#####
cor.mat <- table(traindata_pred, traindata.set$subtype)
library(pheatmap)
library(RColorBrewer)
breaksList = seq(0, 1, by = 0.01)
# Pairwise correlation between samples (columns)
png("./plots/105Heatmap_training_cor.png", width = 4, height = 4, units = "in", res = 300)
pheatmap(
  cor.mat/rowSums(cor.mat), scale = "none", 
  cluster_rows = F, cluster_cols = F,
  show_rownames = T, show_colnames = T,
  annotation_legend = T, display_numbers = cor.mat, fontsize_number=16,
  border_color = "grey",
  color = colorRampPalette(c("white", "deeppink"))(length(breaksList)), # Defines the vector of colors for the legend (it has to be of the same lenght of breaksList)
  main = "Training"
)
dev.off()



cor.mat <- table(test_pred, info.Abida2019$subtype_anno[which(!rownames(RF.df) %in% rownames(traindata.set) )])
breaksList = seq(0, 1, by = 0.01)
# Pairwise correlation between samples (columns)
png("./plots/105Heatmap_test_cor.png", width = 4, height = 4, units = "in", res = 300)
pheatmap(
  cor.mat/rowSums(cor.mat), scale = "none", 
  cluster_rows = F, cluster_cols = F,
  show_rownames = T, show_colnames = T,
  annotation_legend = T, display_numbers = cor.mat, fontsize_number=16,
  border_color = "grey",
  color = colorRampPalette(c("white", "deeppink"))(length(breaksList)), # Defines the vector of colors for the legend (it has to be of the same lenght of breaksList)
  main = "Test"
)
dev.off()





####test set ######
load("./105RFmodel.RData")
rawdata <- read.table("./RNAseq_alignment/mRNA_name_twocohort.txt", header = T, sep = "\t", row.names = 1,
                       stringsAsFactors = F)
rownames(rawdata)
rownames(rawdata) <-  gsub("-", "_", rownames(rawdata))
rownames(rawdata) <-  gsub("\\.", "_", rownames(rawdata))
gene_kilobase <- as.numeric(rawdata$Length)/1000
tmp <- as.data.frame(rawdata[,6:ncol(rawdata)])
tmp <- apply(tmp, 2, as.numeric)
RPK <- tmp/gene_kilobase
coverage <- colSums(RPK[,1:ncol(RPK)])/1000000
RPK <- t(RPK)
TPM <- t(RPK/coverage)
TPM <- round(TPM, 4)
colSums(TPM)
head(TPM)
TPM <- as.data.frame(TPM)
rownames(TPM) <- rownames(rawdata)
save(TPM, file = "./mRNA_name_twocohort.rds")

#limma 
gene.sig <- read.csv("./genesig_limma.csv", header = T, stringsAsFactors = F)
gene.sig <- gene.sig$gene.sig


#clustering using limma feature
test.set <- log2(TPM+1)
#test.set <- test.set[rownames(eSet),]
test.set <- test.set[gene.sig,]
test.set <- as.data.frame(t(test.set))

#RF
library(randomForest)
RF.df <- as.data.frame(t(eSet[gene.sig,]))
RF.df <- cbind(RF.df, info.Abida2019$subtype_anno) #
colnames(RF.df)[ncol(RF.df)] <- "subtype"
set.seed(3227)
blood_rf <- randomForest(subtype ~ ., data = RF.df, ntree = 100, proximity = T)

#clustering
dist.fc <- hclust(dist(test.set,method = "euclidean"),method = "ward.D2")
plot(dist.fc, hang=-1, labels=FALSE, main="test set sample clustering", sub="")
branches.fc <- cutree(dist.fc, k=4)
test.set$subtype <- branches.fc
test.set$subtype <- paste0("subtype",test.set$subtype)

#prediction 
test_pred <- predict(blood_rf, newdata = test.set)
table(test_pred, test.set$subtype) 
table(test_pred)


rownames(test.set) <- substr(rownames(test.set), start = 13L, stop = 23L)
rownames(test.set) <-  gsub("_s", "", rownames(test.set))
info.met <- data.frame(id = rownames(test.set), subtype_cls = test.set$subtype, subtype_RF = test_pred,
                       stringsAsFactors = F)
test.set <- test.set[,1:(ncol(test.set)-1)]
test.set <- as.data.frame(t(test.set))


####visualization
#using RF results 
info.met$RF_num <- "subtype4"
info.met$RF_num[grep("Basal", info.met$subtype_RF)] <- "subtype1"
info.met$RF_num[grep("HRR", info.met$subtype_RF)] <- "subtype2"
info.met$RF_num[grep("NE", info.met$subtype_RF)] <- "subtype3"
library(pheatmap)
annotation_col = data.frame(
  #cls = info.met$subtype_cls,
  RF = info.met$RF_num
)
rownames(annotation_col) = colnames(test.set)
names(pal.subtype) <- levels(as.factor(info.met$RF_num))
#names(pal.tissue) <- levels(as.factor(info.met$subtype_cls))
breaksList = seq(-1, 2.5, by = 0.01)
# Pairwise correlation between samples (columns)
pheatmap(
  test.set[,order(info.met$RF_num)], scale = "row", 
  clustering_distance_cols = "euclidean", clustering_method = "ward.D2",
  cluster_rows = T, cluster_cols = F,
  show_rownames = F, show_colnames = F,
  annotation_legend = T,
  border_color = NA,
  color = colorRampPalette(rev(brewer.pal(n = 7, name = "RdYlBu")))(length(breaksList)), # Defines the vector of colors for the legend (it has to be of the same lenght of breaksList)
  breaks = breaksList,
  annotation_col = annotation_col,
  annotation_colors  = list(
    #Time = c("white", "firebrick"),
    # subtype = c(subtype1 = "#A6CEE3", subtype2 = "#1F78B4",
    #            subtype3 = "#B2DF8A", subtype4 = "#33A02C"),
    #cls = pal.tissue , 
    RF = pal.subtype
  ),
  main = "Test"
)

png("./plots/105Heatmap_test_gene.sig.png", width = 5, height = 5, units = "in", res = 300)
annotation_col = data.frame(
  tissue = test_pred
)
rownames(annotation_col) = colnames(test.set)
names(pal.subtype) <- levels(as.factor(test_pred))
breaksList = seq(-0.8, 0.8, by = 0.01)
pheatmap(
  test.set[,order(test_pred)], scale = "row", 
  clustering_distance_cols = "euclidean", clustering_method = "ward.D2",
  cluster_rows = T, cluster_cols = F,
  show_rownames = F, show_colnames = F,
  annotation_legend = T,
  border_color = NA,
  color = colorRampPalette(rev(brewer.pal(n = 7, name = "RdYlBu")))(length(breaksList)), # Defines the vector of colors for the legend (it has to be of the same lenght of breaksList)
  breaks = breaksList,
  annotation_col = annotation_col,
  annotation_colors  = list(
    #Time = c("white", "firebrick"),
    # subtype = c(subtype1 = "#A6CEE3", subtype2 = "#1F78B4",
    #            subtype3 = "#B2DF8A", subtype4 = "#33A02C"),
    tissue = pal.subtype
  ),
  main = "Test"
)
dev.off()


save(test.set, info.met, file = "./met_twocohort.RData")

save(gene.sig, blood_rf, 
     file = "./105RFmodel.RData")
