library(RColorBrewer)
pal.subtype <- brewer.pal(4, "Set1")
###read fusion files
dir <- "./alignment_fusion/"
fusion.files <- list.files(path = dir,pattern = '*predictions.tsv$', recursive = T)

fusion.files[116]
fusion.files[136]

fusion <- c()
for (i in c(1:115, 117:135, 137:154)) {
  tmp <- read.table(paste(dir, fusion.files[i], sep = ""), 
                    sep = '\t', header = F, stringsAsFactors = F)
  print(paste(i,"file, read done", sep = " "))
  tmp <- tmp[,c(1,2,5:8,11,12,17)]#subset column
  colnames(tmp) <- c("FusionName", "ReadCount", "LeftGene", "LeftBreakpoint", 
                     "RightGene", "RightBreakpoint", "LargeAnchorSupport", "FFPM", "anno")
  tmp$sample <- rep(substr(fusion.files[i], start = 1L, stop = 11L), nrow(tmp))
  
  fusion <- rbind(fusion, tmp)
}
fusion$sample <- gsub("/s", "", fusion$sample)

write.csv(fusion, file = "./fusion.csv",sep = ",", row.names = F)

fusion.df <- aggregate(fusion$FFPM, by=list(SRR=fusion$sample), FUN=sum)
colnames(fusion.df)[2] <- "FFPM"
nofusion <- data.frame(SRR = c("SRR11355895","SRR11355915"), 
                       FFPM = rep(0, 2))
fusion.df <- rbind(fusion.df, nofusion)
fusion.df <- fusion.df[order(fusion.df$SRR),]



##match fusion data with eSet valid data
load(file = "./met_twocohort.RData")
table(info.met$RF_num)
info.met$FFPM <-  fusion.df[match(info.met$id, fusion.df$SRR),"FFPM"]

png("./plots/107Boxplot_FFPM.png", width = 4, height = 4, units = "in", res = 300)
boxplot(FFPM ~ RF_num , data = info.met, col = pal.subtype, 
        notch = F, ylim = c(0,45))
kruskal.test(info.met$FFPM ~ info.met$RF_num)
TukeyHSD(aov(info.met$FFPM ~ info.met$RF_num))
dev.off()


#####Circos plot ####
library(circlize)

bed1.df <- c()
bed2.df <- c()
fusion.name <- c()
for (i in c(1:138,147:154)) { 
  #test fusion files 
  tmp <- tryCatch(read.table(paste(dir, fusion.files[i], sep = ""),sep = '\t', header = F, stringsAsFactors = F), 
                  error = function(e) paste("no fusion in this sample"))
  if (tmp == "no fusion in this sample") {
    print("-------no fusion in this sample--------")
  } else {
    fusion.df <- read.table(paste(dir, fusion.files[i], sep = ""),sep = '\t', header = F, stringsAsFactors = F)
    fusion.df <- fusion.df[,c(1,6,8)] # genomic location
    tmp <- unlist(strsplit(fusion.df$V6, ":"))
    tmp <- matrix(tmp, ncol = 3, byrow = T)
    tmp <- as.data.frame(tmp)
    fusion.df <- cbind(fusion.df,tmp)
    tmp <- unlist(strsplit(fusion.df$V8, ":"))
    tmp <- matrix(tmp, ncol = 3, byrow = T)
    tmp <- as.data.frame(tmp)
    fusion.df <- cbind(fusion.df,tmp)
    fusion.df <- fusion.df[,c(1,4,5,7,8)]
    
    bed1 <- fusion.df[,c(1,2,3)]
    colnames(bed1) <- c("name", "chr", "start")
    bed1$chr <- as.character(bed1$chr)
    bed1$start <- as.integer(as.character(bed1$start))
    bed1$end <- bed1$start+1000
    tmp.name <- bed1$name
    bed1 <- bed1[,-1] 
    fusion.name <- c(fusion.name, tmp.name)
    bed1$subtype <- rep(info.met$RF_num[i], nrow(bed1)) #subtype names and number
    bed1.df <- rbind(bed1.df, bed1)
    bed2 <- fusion.df[,c(1,4,5)]
    colnames(bed2) <- c("name", "chr", "start")
    bed2$chr <- as.character(bed2$chr)
    bed2$start <- as.integer(as.character(bed2$start))
    bed2$end <- bed2$start+ 1000
    bed2 <- bed2[,-1]
    bed2$subtype <- rep(info.met$RF_num[i], nrow(bed2))
    bed2.df <- rbind(bed2.df, bed2)
    
    print(paste("----------plotting_", i, "-----------", sep = ""))
  }
}

fusion.df_ERG <- cbind(bed1.df, bed2.df)
fusion.df_ERG$fusion.name <- fusion.name
fusion.df_ERG <- fusion.df_ERG[grep("TMPRSS2--ERG", fusion.df_ERG$fusion.name),]


pdf("./plots/107Circos_twocohorts.pdf", width = 7, height = 7)
circos.initializeWithIdeogram()
circos.genomicLink(bed1.df, bed2.df, 
                   col = "black", lwd = 10,
                   border = NA)
dev.off()


library(RColorBrewer)
pal.subtype <- brewer.pal(8, "Set1")
idx.ec <- which(!(bed1.df$chr == bed2.df$chr)) #subset interchromosomal fusions only 
ecbed1 <- bed1.df[idx.ec,]
ecbed2 <- bed2.df[idx.ec,]

pdf("./plots/107Circos_merged_interchromosome.pdf", width = 4, height = 4)
circos.initializeWithIdeogram()
circos.genomicLink(ecbed1, ecbed2, 
                   col = "black", lwd = nrow(ecbed1),
                   border = NA)
subtype.level <- levels(as.factor(bed1.df$subtype))
for (i in 1:4) {
  tmpbed1 <- ecbed1[ecbed1$subtype == subtype.level[i],]
  tmpbed2 <- ecbed2[ecbed2$subtype == subtype.level[i],]
  circos.initializeWithIdeogram()
  circos.genomicLink(tmpbed1, tmpbed2, 
                     col = pal.subtype[i], lwd = nrow(ecbed1),
                     border = NA)
}
dev.off()

pdf("./plots/107Circos_merged_subtype.pdf", width = 7, height = 7)
for (i in 1:4) {
  tmpbed1 <- bed1.df[bed1.df$subtype == subtype.level[i],]
  tmpbed2 <- bed2.df[bed2.df$subtype == subtype.level[i],]
  circos.initializeWithIdeogram()
  circos.genomicLink(tmpbed1, tmpbed2, 
                     col = pal.subtype[i], lwd = 10,
                     border = NA)
}
dev.off()

#interchromosomal fusion frequency
ecbed1$name <- fusion.name[idx.ec]
ecbed1
interbed <- cbind(ecbed1, ecbed2)
colnames(interbed)
interbed <- interbed[,c(5,4,1,2,6,7)]
table(interbed$subtype)# fusion number in each subtype
table(info.met$subtype)
fusion.df <- data.frame(fusion.number = c(19, 11, 53, 8), sample.size = c(67,38,59,15), 
                        subtype = paste("subtype", 1:4, sep = ""),
                        stringsAsFactors = F)
fusion.df$fusion.freq <- fusion.df$fusion.number / (fusion.df$sample.size * 3) # per GegaBases
pdf("./plots/107Barplot_interchromosomal_fusion_freq.pdf", width = 5, height = 5)
barplot(fusion.freq~subtype, data = fusion.df, col = pal.subtype,
        main = "Gene Fusion Frequency", ylim = c(0,0.5),
        xlab = "Subtypes", ylab = "Fusion frequency (per GetaBase)")
dev.off()


# most fused gene 
idx.sub3.fusion <- which(interbed$subtype == "subtype3")
fused.gene.df <- as.data.frame(sort(table(unlist(strsplit(interbed$name[idx.sub3.fusion], "--"))), decreasing = T))
fused.gene.df$subtype <- rep("subtype3", nrow(fused.gene.df))

fusion.files <- fusion.files[c(1:138,147:154)] #remove missed files 
#most freq fusion in all and subtypes
fusion.df <- c()
for (i in c(1:146)) { 
  #test fusion files 
  tmp <- tryCatch(read.table(paste(dir, fusion.files[i], sep = ""),sep = '\t', header = F, stringsAsFactors = F), 
                  error = function(e) paste("no fusion in this sample"))
  if (tmp == "no fusion in this sample") {
    print("-------no fusion in this sample--------")
  } else {
    tmp <- read.table(paste(dir, fusion.files[i], sep = ""),sep = '\t', header = F, stringsAsFactors = F)
    tmp <- tmp[,c(1,8)] # genomic location
    tmp$id <- substr(fusion.files[i], start = 1L, stop = 11L)
    tmp$subtype <- info.met$RF_num[i]
    tmp <- tmp[,c(1,3,4)]
    fusion.df <- rbind(fusion.df,tmp)
    print(i)
  }  
}

length(table(fusion.df[which(fusion.df$V1 == "TMPRSS2--ERG" & fusion.df$subtype == "subtype1"),c(1,2)] ))
length(table(fusion.df[fusion.df$V1 == "TMPRSS2--ERG" & fusion.df$subtype == "subtype2",c(1,2)] ))
length(table(fusion.df[fusion.df$V1 == "TMPRSS2--ERG" & fusion.df$subtype == "subtype3",c(1,2)] ))
length(table(fusion.df[fusion.df$V1 == "TMPRSS2--ERG" & fusion.df$subtype == "subtype4",c(1,2)] ))
#23/55 = 41.82%
#1/4 = 25%
#6/28 = 21.43%
#16/59 = 27.12%

length(table(fusion.df[fusion.df$V1 == "COL4A5--ACPP" & fusion.df$subtype == "subtype1",c(1,2)] ))
length(table(fusion.df[fusion.df$V1 == "COL4A5--ACPP" & fusion.df$subtype == "subtype2",c(1,2)] ))
length(table(fusion.df[fusion.df$V1 == "COL4A5--ACPP" & fusion.df$subtype == "subtype3",c(1,2)] ))
length(table(fusion.df[fusion.df$V1 == "COL4A5--ACPP" & fusion.df$subtype == "subtype4",c(1,2)] ))
#1/55 = 1.82%
#1/4 = 25%
#0/28 = 0%
#0/59 = 0%

length(table(fusion.df[fusion.df$V1 == "OFCC1--STXBP5L" & fusion.df$subtype == "subtype1",c(1,2)] ))
length(table(fusion.df[fusion.df$V1 == "OFCC1--STXBP5L" & fusion.df$subtype == "subtype2",c(1,2)] ))
length(table(fusion.df[fusion.df$V1 == "OFCC1--STXBP5L" & fusion.df$subtype == "subtype3",c(1,2)] ))
length(table(fusion.df[fusion.df$V1 == "OFCC1--STXBP5L" & fusion.df$subtype == "subtype4",c(1,2)] ))
#1/55 = 1.82%
#0/4 = 0
#4/28 = 14.29%
#0/59 = 0%

length(table(fusion.df[fusion.df$V1 == "NBEAP1--IGH@-ext" & fusion.df$subtype == "subtype1",c(1,2)] ))/55
length(table(fusion.df[fusion.df$V1 == "NBEAP1--IGH@-ext" & fusion.df$subtype == "subtype2",c(1,2)] ))/4
length(table(fusion.df[fusion.df$V1 == "NBEAP1--IGH@-ext" & fusion.df$subtype == "subtype3",c(1,2)] ))/28
length(table(fusion.df[fusion.df$V1 == "NBEAP1--IGH@-ext" & fusion.df$subtype == "subtype4",c(1,2)] ))/59


length(table(fusion.df[fusion.df$subtype == "subtype1",2] ))/55
length(table(fusion.df[fusion.df$subtype == "subtype2",2] ))/4
length(table(fusion.df[fusion.df$subtype == "subtype3",2] ))/28
length(table(fusion.df[fusion.df$subtype == "subtype4",2] ))/59



fusion.type <- c()
tmp <- as.data.frame(table(fusion.df[fusion.df$subtype =="subtype1", c(1,3)]))
tmp <- tmp[order(tmp$Freq, decreasing = T),]
tmp$Pctg <- tmp$Freq/55
fusion.type <- rbind(fusion.type, tmp)
#subtype 1 TMPRSS2--ERG 51/55
tmp <- as.data.frame(table(fusion.df[fusion.df$subtype =="subtype2", c(1,3)]))
tmp <- tmp[order(tmp$Freq, decreasing = T),]
tmp$Pctg <- tmp$Freq/4
fusion.type <- rbind(fusion.type, tmp)
#subtype 2 COL4A5--ACPP TMPRSS2--ERG  2/4
tmp <- as.data.frame(table(fusion.df[fusion.df$subtype =="subtype3", c(1,3)]))
tmp <- tmp[order(tmp$Freq, decreasing = T),]
tmp$Pctg <- tmp$Freq/28
fusion.type <- rbind(fusion.type, tmp)
#subtype 3 TMPRSS2--ERG  10/28
tmp <- as.data.frame(table(fusion.df[fusion.df$subtype =="subtype4", c(1,3)]))
tmp <- tmp[order(tmp$Freq, decreasing = T),]
tmp$Pctg <- tmp$Freq/59
fusion.type <- rbind(fusion.type, tmp)
#subtype 4  TMPRSS2--ERG  38/59
table(info.met$RF_num)

fusion.type[grep("TMPRSS2--ERG", fusion.type$V1),]
png("./plots/107Barplot_TMPRSS-ERG.png", width = 4, height = 4, units = "in", res = 300)
barplot(Pctg ~ subtype , data = fusion.type[grep("TMPRSS2--ERG", fusion.type$V1),], 
        col = pal.subtype, ylim = c(0,1), ylab = c("Percentage"))
dev.off()

fusion.type[grep("subtype2", fusion.type$subtype),]
fusion.type[grep("COL4A5", fusion.type$V1),]
fusion.type[grep("subtype3", fusion.type$subtype),]
fusion.type[grep("OFCC1", fusion.type$V1),]
fusion.type[grep("subtype4", fusion.type$subtype),]
fusion.type[grep("OFCC1", fusion.type$V1),]

save(fusion.df, file = "./fusion.df.rds")
save(fusion.type, file = "./fusion.type.rds")



###TMPRSS2-ERG fusion in chr21
table(fusion.df_ERG[,2])
table(fusion.df_ERG[,6])
bed1_TMPRSS2 <- fusion.df_ERG[,c(1:4)]
bed2_ERG <- fusion.df_ERG[,c(5:8)]
subtype.level <- levels(as.factor(bed1_TMPRSS2$subtype))
cir.range = data.frame(
  chr  = c("ERG", "TMPRSS2"),
  start = c(38380027, 41466142),
  end   = c(38661694, 41531116))
bed1_TMPRSS2$chr <- "TMPRSS2"
bed2_ERG$chr <- "ERG"

pdf("./plots/107Circos_twocohorts_chr21.pdf", width = 4, height = 4)
#circos.initializeWithIdeogram(chromosome.index = "chr21")
circos.genomicInitialize(cir.range)
circos.track(ylim = c(0, 1), 
             bg.col = c("#F46D43", "#FEE08B"), 
             bg.border = NA, track.height = 0.05)
circos.genomicLink(bed1_TMPRSS2, bed2_ERG, 
                   col = "black", lwd = 10,
                   border = NA)
for (i in 1:4) {
  tmpbed1 <- bed1_TMPRSS2[bed1_TMPRSS2$subtype == subtype.level[i],]
  tmpbed2 <- bed2_ERG[bed2_ERG$subtype == subtype.level[i],]
  circos.genomicInitialize(cir.range)
  circos.track(ylim = c(0, 1), 
               bg.col = c("#F46D43", "#FEE08B"), 
               bg.border = NA, track.height = 0.05)
  circos.genomicLink(tmpbed1, tmpbed2, 
                     col = pal.subtype[i], lwd = 10,
                     border = NA)
}
dev.off()


bed2_ERG[bed2_ERG$subtype == "subtype2",]
bed2_ERG[bed2_ERG$subtype == "subtype3",]
bed2_ERG[bed2_ERG$subtype == "subtype4",]



library(RColorBrewer)
pal.grade <- brewer.pal(8, "Dark2")
pal.batch <- brewer.pal(8, "Accent")
pal.subtype <- brewer.pal(8, "Set1")

pdf("./plots/107Boxplot_fusionFreq.pdf", width = 4, height = 5)
boxplot(info.met$fusion.freq ~ info.met$RF_num, col = pal.subtype, 
        main = "Gene Fusion Frequency", 
        xlab = "Subtypes", ylab = "Number of Fusions")
boxplot(info.met$fusion.freq ~ info.met$grade, col = pal.grade, 
        main = "Gene Fusion Frequency", 
        xlab = "Grade", ylab = "Number of Fusions")
dev.off()

#subtypes ANOVA
summary(aov(sampleinfo$fusion.freq ~ sampleinfo$subtype))
TukeyHSD(aov(sampleinfo$fusion.freq ~ sampleinfo$subtype))
#grade ANOVA
summary(aov(sampleinfo$fusion.freq ~ sampleinfo$grade))
TukeyHSD(aov(sampleinfo$fusion.freq ~ sampleinfo$grade))



###fusion feature in each subtype
sort(table(fusion_merge$FusionName))

sampleinfo[sampleinfo$sra %in% c("SRR10042635","SRR10042652", "SRR10042681" ),]



